| foldedt-package | R Documentation |
Maximum likelihood estimation of the folded t and related distributions. Probability and density functions, and random generation are also included.
| Package: | foldedt |
| Type: | Package |
| Version: | 1.0 |
| Date: | 2026-03-18 |
| License: | GPL-2 |
Michail Tsagris mtsagris@uoc.gr.
Michail Tsagris mtsagris@uoc.gr.
Psarakis and Panaretos (1990). The folded t distribution. Communications in Statistics–Theory and Methods, 19(7): 2717–2734.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.