| halft1.mle | R Documentation |
MLE of the half t distribution with unit scatter parameter.
halft1.mle(x, tol = 1e-07)
x |
A numerical vector with positive real numbers. |
tol |
The tolerance level up to which the maximisation stops set to 1e-07 by default. |
The half-t distribution with \nu > 0 degrees of freedom, zero location parameter and unit scatter parameter has density:
f(x) = \frac{2\Gamma\left(\frac{\nu+1}{2}\right)}{\sqrt{\nu\pi}\,\Gamma\left(\frac{\nu}{2}\right)} \left(1 + \frac{x^2}{\nu}\right)^{-\frac{\nu+1}{2}}, \quad x \geq 0.
A list including:
iters |
The number of iterations required by the Newton-Raphson algorithm. |
nu |
The estimated degrees of freedom of the half t distribution. |
loglik |
The value of the maximised log-likelihood. |
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
Psarakis and Panaretos (1990). The folded t distribution. Communications in Statistics–Theory and Methods, 19(7): 2717–2734.
https://en.wikipedia.org/wiki/Folded-t_and_half-t_distributions
halft.mle, dfoldedt
x <- abs( rt(1000, 5) )
halft.mle(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.